@@ -2,10 +2,12 @@
 #' @import checkmate
 #' @import mlr3misc
 #' @importFrom R6 R6Class
-#' @importFrom stats runif
+#' @importFrom stats runif rnorm
 "_PACKAGE"
 
-.onLoad = function(libname, pkgname) {
+.onLoad = function(libname, pkgname) { # nolint
   # nocov start
   backports::import(pkgname)
 } # nocov end
+
+leanify_package()
